@@ -6,9 +6,9 @@
 # https://github.com/msberends/AMR                                     #
 #                                                                      #
 # PLEASE CITE THIS SOFTWARE AS:                                        #
-# Berends MS, Luz CF, Friedrich AW, Sinha BNM, Albers CJ, Glasner C    #
-# (2022). AMR: An R Package for Working with Antimicrobial Resistance  #
-# Data. Journal of Statistical Software, 104(3), 1-31.                 #
+# Berends MS, Luz CF, Friedrich AW, et al. (2022).                     #
+# AMR: An R Package for Working with Antimicrobial Resistance Data.    #
+# Journal of Statistical Software, 104(3), 1-31.                       #
 # https://doi.org/10.18637/jss.v104.i03                                #
 #                                                                      #
 # Developed at the University of Groningen and the University Medical  #
@@ -24,19 +24,20 @@
 # useful, but it comes WITHOUT ANY WARRANTY OR LIABILITY.              #
 #                                                                      #
 # Visit our website for the full manual and a complete tutorial about  #
-# how to conduct AMR data analysis: https://msberends.github.io/AMR/   #
+# how to conduct AMR data analysis: https://amr-for-r.org              #
 # ==================================================================== #
 
 #' Transform Input to an Antibiotic ID
 #'
-#' Use this function to determine the antibiotic drug code of one or more antibiotics. The data set [antibiotics] will be searched for abbreviations, official names and synonyms (brand names).
-#' @param x a [character] vector to determine to antibiotic ID
-#' @param flag_multiple_results a [logical] to indicate whether a note should be printed to the console that probably more than one antibiotic drug code or name can be retrieved from a single input value.
-#' @param info a [logical] to indicate whether a progress bar should be printed - the default is `TRUE` only in interactive mode
-#' @param ... arguments passed on to internal functions
+#' Use this function to determine the antimicrobial drug code of one or more antimicrobials. The data set [antimicrobials] will be searched for abbreviations, official names and synonyms (brand names).
+#' @param x A [character] vector to determine to antibiotic ID.
+#' @param flag_multiple_results A [logical] to indicate whether a note should be printed to the console that probably more than one antibiotic drug code or name can be retrieved from a single input value.
+#' @param language Language to coerce input values from any of the `r length(LANGUAGES_SUPPORTED)` supported languages - default to the system language if supported (see [get_AMR_locale()]).
+#' @param info A [logical] to indicate whether a progress bar should be printed - the default is `TRUE` only in interactive mode.
+#' @param ... Arguments passed on to internal functions.
 #' @rdname as.ab
 #' @inheritSection WHOCC WHOCC
-#' @details All entries in the [antibiotics] data set have three different identifiers: a human readable EARS-Net code (column `ab`, used by ECDC and WHONET), an ATC code (column `atc`, used by WHO), and a CID code (column `cid`, Compound ID, used by PubChem). The data set contains more than 5,000 official brand names from many different countries, as found in PubChem. Not that some drugs contain multiple ATC codes.
+#' @details All entries in the [antimicrobials] data set have three different identifiers: a human readable EARS-Net code (column `ab`, used by ECDC and WHONET), an ATC code (column `atc`, used by WHO), and a CID code (column `cid`, Compound ID, used by PubChem). The data set contains more than 5,000 official brand names from many different countries, as found in PubChem. Not that some drugs contain multiple ATC codes.
 #'
 #' All these properties will be searched for the user input. The [as.ab()] can correct for different forms of misspelling:
 #'
@@ -51,15 +52,15 @@
 #'
 #' You can add your own manual codes to be considered by [as.ab()] and all [`ab_*`][ab_property()] functions, see [add_custom_antimicrobials()].
 #' @section Source:
-#' World Health Organization (WHO) Collaborating Centre for Drug Statistics Methodology: \url{https://www.whocc.no/atc_ddd_index/}
+#' World Health Organization (WHO) Collaborating Centre for Drug Statistics Methodology: \url{https://atcddd.fhi.no/atc_ddd_index/}
 #'
 #' European Commission Public Health PHARMACEUTICALS - COMMUNITY REGISTER: \url{https://ec.europa.eu/health/documents/community-register/html/reg_hum_atc.htm}
 #' @aliases ab
 #' @return A [character] [vector] with additional class [`ab`]
 #' @seealso
-#' * [antibiotics] for the [data.frame] that is being used to determine ATCs
+#' * [antimicrobials] for the [data.frame] that is being used to determine ATCs
 #' * [ab_from_text()] for a function to retrieve antimicrobial drugs from clinical text (from health care records)
-#' @inheritSection AMR Reference Data Publicly Available
+#' @inheritSection AMR Download Our Reference Data
 #' @export
 #' @examples
 #' # these examples all return "ERY", the ID of erythromycin:
@@ -67,12 +68,10 @@
 #' as.ab("J 01 FA 01")
 #' as.ab("Erythromycin")
 #' as.ab("eryt")
-#' as.ab("   eryt 123")
 #' as.ab("ERYT")
 #' as.ab("ERY")
 #' as.ab("eritromicine") # spelled wrong, yet works
 #' as.ab("Erythrocin") # trade name
-#' as.ab("Romycin") # trade name
 #'
 #' # spelling from different languages and dyslexia are no problem
 #' ab_atc("ceftriaxon")
@@ -92,22 +91,20 @@
 #'     set_ab_names(where(is.sir), property = "atc")
 #' }
 #' }
-as.ab <- function(x, flag_multiple_results = TRUE, info = interactive(), ...) {
+as.ab <- function(x, flag_multiple_results = TRUE, language = get_AMR_locale(), info = interactive(), ...) {
   meet_criteria(x, allow_class = c("character", "numeric", "integer", "factor"), allow_NA = TRUE)
   meet_criteria(flag_multiple_results, allow_class = "logical", has_length = 1)
+  language <- validate_language(language)
   meet_criteria(info, allow_class = "logical", has_length = 1)
 
-  if (is.ab(x)) {
-    return(x)
-  }
-  if (all(x %in% c(AMR_env$AB_lookup$ab, NA))) {
-    # all valid AB codes, but not yet right class
+  if (is.ab(x) || all(x %in% c(AMR_env$AB_lookup$ab, NA))) {
+    # all valid AB codes, but not yet right class or might have additional attributes as AMR selector
+    attributes(x) <- NULL
     return(set_clean_class(x,
       new_class = c("ab", "character")
     ))
   }
 
-  initial_search <- is.null(list(...)$initial_search)
   already_regex <- isTRUE(list(...)$already_regex)
   fast_mode <- isTRUE(list(...)$fast_mode)
 
@@ -117,8 +114,8 @@ as.ab <- function(x, flag_multiple_results = TRUE, info = interactive(), ...) {
   # remove diacritics
   x <- iconv(x, from = "UTF-8", to = "ASCII//TRANSLIT")
   x <- gsub('"', "", x, fixed = TRUE)
-  x <- gsub("(specimen|specimen date|specimen_date|spec_date|gender|^dates?$)", "", x, ignore.case = TRUE, perl = TRUE)
-  # penicillin is a special case: we call it so, but then mean benzylpenicillin
+  x <- gsub("(specimen|specimen date|specimen_date|spec_date|gender|^dates?$|animal|host($|[a-z]))", "", x, ignore.case = TRUE, perl = TRUE)
+  # penicillin is a special case: we call it so, but then most often mean benzylpenicillin
   x[x %like_case% "^PENICILLIN" & x %unlike_case% "[ /+-]"] <- "benzylpenicillin"
   x_bak_clean <- x
   if (already_regex == FALSE) {
@@ -127,20 +124,26 @@ as.ab <- function(x, flag_multiple_results = TRUE, info = interactive(), ...) {
 
   x <- unique(x_bak_clean) # this means that every x is in fact generalise_antibiotic_name(x)
   x_new <- rep(NA_character_, length(x))
+  x_uncertain <- character(0)
   x_unknown <- character(0)
   x_unknown_ATCs <- character(0)
 
   note_if_more_than_one_found <- function(found, index, from_text) {
-    if (isTRUE(initial_search) && isTRUE(length(from_text) > 1)) {
-      abnames <- ab_name(from_text, tolower = TRUE, initial_search = FALSE)
+    if (isTRUE(length(from_text) > 1)) {
+      abnames <- ab_name(from_text, tolower = TRUE)
       if (ab_name(found[1L], language = NULL) %like% "(clavulanic acid|(avi|tazo|mono|vabor)bactam)") {
         abnames <- abnames[!abnames %in% c("clavulanic acid", "avibactam", "tazobactam", "vaborbactam", "monobactam")]
       }
       if (length(abnames) > 1) {
-        message_(
-          "More than one result was found for item ", index, ": ",
-          vector_and(abnames, quotes = FALSE)
-        )
+        if (toupper(paste(abnames, collapse = " ")) %in% AMR_env$AB_lookup$generalised_name) {
+          # if the found values combined is a valid AB, return that
+          found <- AMR_env$AB_lookup$ab[match(toupper(paste(abnames, collapse = " ")), AMR_env$AB_lookup$generalised_name)][1]
+        } else if (isTRUE(info)) {
+          message_(
+            "More than one result was found for item ", index, ": ",
+            vector_and(abnames, quotes = FALSE)
+          )
+        }
       }
     }
     found[1L]
@@ -150,12 +153,13 @@ as.ab <- function(x, flag_multiple_results = TRUE, info = interactive(), ...) {
   known_names <- x %in% AMR_env$AB_lookup$generalised_name
   x_new[known_names] <- AMR_env$AB_lookup$ab[match(x[known_names], AMR_env$AB_lookup$generalised_name)]
   known_codes_ab <- x %in% AMR_env$AB_lookup$ab
-  known_codes_atc <- vapply(FUN.VALUE = logical(1), x, function(x_) x_ %in% unlist(AMR_env$AB_lookup$atc), USE.NAMES = FALSE)
+  known_codes_atc <- vapply(FUN.VALUE = logical(1), gsub(" ", "", x), function(x_) x_ %in% unlist(AMR_env$AB_lookup$atc), USE.NAMES = FALSE)
+  known_codes_synonyms <- vapply(FUN.VALUE = logical(1), gsub(" ", "", tolower(x)), function(x_) x_ %in% tolower(unlist(AMR_env$AB_lookup$synonyms)), USE.NAMES = FALSE)
   known_codes_cid <- x %in% AMR_env$AB_lookup$cid
   x_new[known_codes_ab] <- AMR_env$AB_lookup$ab[match(x[known_codes_ab], AMR_env$AB_lookup$ab)]
   x_new[known_codes_atc] <- AMR_env$AB_lookup$ab[vapply(
     FUN.VALUE = integer(1),
-    x[known_codes_atc],
+    gsub(" ", "", x[known_codes_atc]),
     function(x_) {
       which(vapply(
         FUN.VALUE = logical(1),
@@ -165,24 +169,42 @@ as.ab <- function(x, flag_multiple_results = TRUE, info = interactive(), ...) {
     },
     USE.NAMES = FALSE
   )]
+  x_new[known_codes_synonyms] <- AMR_env$AB_lookup$ab[vapply(
+    FUN.VALUE = integer(1),
+    gsub(" ", "", tolower(x[known_codes_synonyms])),
+    function(x_) {
+      which(vapply(
+        FUN.VALUE = logical(1),
+        AMR_env$AB_lookup$synonyms,
+        function(syns) x_ %in% tolower(syns)
+      ))[1L]
+    },
+    USE.NAMES = FALSE
+  )]
   x_new[known_codes_cid] <- AMR_env$AB_lookup$ab[match(x[known_codes_cid], AMR_env$AB_lookup$cid)]
   previously_coerced <- x %in% AMR_env$ab_previously_coerced$x
   x_new[previously_coerced & is.na(x_new)] <- AMR_env$ab_previously_coerced$ab[match(x[is.na(x_new) & x %in% AMR_env$ab_previously_coerced$x], AMR_env$ab_previously_coerced$x)]
-  already_known <- known_names | known_codes_ab | known_codes_atc | known_codes_cid | previously_coerced
+  if (any(previously_coerced) && isTRUE(info) && message_not_thrown_before("as.ab", entire_session = TRUE)) {
+    message_(
+      "Returning previously coerced ",
+      ifelse(length(unique(which(x[which(previously_coerced)] %in% x_bak_clean))) > 1, "value for an antimicrobial", "values for various antimicrobials"),
+      ". Run `ab_reset_session()` to reset this. This note will be shown once per session."
+    )
+  }
+
+  already_known <- known_names | known_codes_ab | known_codes_atc | known_codes_synonyms | known_codes_cid | previously_coerced
 
   # fix for NAs
   x_new[is.na(x)] <- NA
   already_known[is.na(x)] <- FALSE
 
-  if (isTRUE(initial_search) && sum(already_known) < length(x)) {
+  if (sum(already_known) < length(x)) {
     progress <- progress_ticker(n = sum(!already_known), n_min = 25, print = info) # start if n >= 25
     on.exit(close(progress))
   }
 
   for (i in which(!already_known)) {
-    if (isTRUE(initial_search)) {
-      progress$tick()
-    }
+    progress$tick()
 
     if (is.na(x[i]) || is.null(x[i])) {
       next
@@ -201,8 +223,14 @@ as.ab <- function(x, flag_multiple_results = TRUE, info = interactive(), ...) {
       next
     }
 
+    # screening, but written without the hyphen, e.g., FOXS instead of FOX-S
+    if (substr(x[i], 4, 4) == "S" && paste0(substr(x[i], 1, 3), "-S") %in% AMR_env$AB_lookup$ab) {
+      x_new[i] <- paste0(substr(x[i], 1, 3), "-S")
+      next
+    }
+
     if (fast_mode == FALSE && flag_multiple_results == TRUE && x[i] %like% "[ ]") {
-      from_text <- tryCatch(suppressWarnings(ab_from_text(x[i], initial_search = FALSE, translate_ab = FALSE)[[1]]),
+      from_text <- tryCatch(suppressWarnings(ab_from_text(x[i], translate_ab = FALSE)[[1]]),
         error = function(e) character(0)
       )
     } else {
@@ -251,7 +279,12 @@ as.ab <- function(x, flag_multiple_results = TRUE, info = interactive(), ...) {
 
     # length of input is quite long, and Levenshtein distance is only max 2
     if (nchar(x[i]) >= 10) {
-      levenshtein <- as.double(utils::adist(x[i], AMR_env$AB_lookup$generalised_name))
+      levenshtein <- as.double(utils::adist(x[i], AMR_env$AB_lookup$generalised_name,
+        ignore.case = FALSE,
+        fixed = TRUE,
+        costs = c(insertions = 1, deletions = 1, substitutions = 2),
+        counts = FALSE
+      ))
       if (any(levenshtein <= 2)) {
         found <- AMR_env$AB_lookup$ab[which(levenshtein <= 2)]
         x_new[i] <- note_if_more_than_one_found(found, i, from_text)
@@ -295,6 +328,7 @@ as.ab <- function(x, flag_multiple_results = TRUE, info = interactive(), ...) {
       x_new[i] <- note_if_more_than_one_found(found, i, from_text)
       next
     }
+
     # try if name ends with it
     found <- AMR_env$AB_lookup[which(AMR_env$AB_lookup$generalised_name %like% paste0(x_spelling, "$")), "ab", drop = TRUE]
     if (nchar(x[i]) >= 4 && length(found) > 0) {
@@ -313,211 +347,104 @@ as.ab <- function(x, flag_multiple_results = TRUE, info = interactive(), ...) {
       next
     }
 
-    # INITIAL SEARCH - More uncertain results ----
-
-    if (isTRUE(initial_search) && fast_mode == FALSE) {
-      # only run on first try
-
-      # try by removing all spaces
-      if (x[i] %like% " ") {
-        found <- suppressWarnings(as.ab(gsub(" +", "", x[i], perl = TRUE), initial_search = FALSE))
-        if (length(found) > 0 && !is.na(found)) {
-          x_new[i] <- note_if_more_than_one_found(found, i, from_text)
-          next
-        }
-      }
-
-      # try by removing all spaces and numbers
-      if (x[i] %like% " " || x[i] %like% "[0-9]") {
-        found <- suppressWarnings(as.ab(gsub("[ 0-9]", "", x[i], perl = TRUE), initial_search = FALSE))
-        if (length(found) > 0 && !is.na(found)) {
-          x_new[i] <- note_if_more_than_one_found(found, i, from_text)
-          next
-        }
-      }
-
-      # transform back from other languages and try again
-      x_translated <- paste(
-        lapply(
-          strsplit(x[i], "[^A-Z0-9]"),
-          function(y) {
-            for (i in seq_len(length(y))) {
-              for (lang in LANGUAGES_SUPPORTED[LANGUAGES_SUPPORTED != "en"]) {
-                y[i] <- ifelse(tolower(y[i]) %in% tolower(TRANSLATIONS[, lang, drop = TRUE]),
-                  TRANSLATIONS[which(tolower(TRANSLATIONS[, lang, drop = TRUE]) == tolower(y[i]) &
-                    !isFALSE(TRANSLATIONS$fixed)), "pattern"],
-                  y[i]
-                )
-              }
-            }
-            generalise_antibiotic_name(y)
-          }
-        )[[1]],
-        collapse = "/"
+    # More uncertain results ----
+    if (fast_mode == FALSE) {
+      ab_df <- AMR_env$AB_lookup
+      ab_df$length_name <- nchar(ab_df$generalised_name)
+      # now retrieve Levensthein distance for name, synonyms, and translated names
+      ab_df$lev_name <- as.double(utils::adist(x[i], ab_df$generalised_name,
+        ignore.case = FALSE,
+        fixed = TRUE,
+        costs = c(insertions = 1, deletions = 1, substitutions = 2),
+        counts = FALSE
+      ))
+      ab_df$lev_syn <- vapply(
+        FUN.VALUE = double(1),
+        ab_df$generalised_synonyms,
+        function(y) {
+          ifelse(all(is.na(y)) || length(y[nchar(y) >= 5]) == 0,
+            999,
+            min(as.double(utils::adist(x[i], y[nchar(y) >= 5],
+              ignore.case = FALSE,
+              fixed = TRUE,
+              costs = c(insertions = 1, deletions = 1, substitutions = 2),
+              counts = FALSE
+            )), na.rm = TRUE)
+          )
+        },
+        USE.NAMES = FALSE
       )
-      x_translated_guess <- suppressWarnings(as.ab(x_translated, initial_search = FALSE))
-      if (!is.na(x_translated_guess)) {
-        x_new[i] <- x_translated_guess
-        next
-      }
-
-      # now also try to coerce brandname combinations like "Amoxy/clavulanic acid"
-      x_translated <- paste(
-        lapply(
-          strsplit(x_translated, "[^A-Z0-9 ]"),
-          function(y) {
-            for (i in seq_len(length(y))) {
-              y_name <- suppressWarnings(ab_name(y[i], language = NULL, initial_search = FALSE))
-              y[i] <- ifelse(!is.na(y_name),
-                y_name,
-                y[i]
-              )
-            }
-            generalise_antibiotic_name(y)
-          }
-        )[[1]],
-        collapse = "/"
-      )
-      x_translated_guess <- suppressWarnings(as.ab(x_translated, initial_search = FALSE))
-      if (!is.na(x_translated_guess)) {
-        x_new[i] <- x_translated_guess
-        next
-      }
-
-      # try by removing all trailing capitals
-      if (x[i] %like_case% "[a-z]+[A-Z]+$") {
-        found <- suppressWarnings(as.ab(gsub("[A-Z]+$", "", x[i], perl = TRUE), initial_search = FALSE))
-        if (!is.na(found)) {
-          x_new[i] <- note_if_more_than_one_found(found, i, from_text)
-          next
-        }
-      }
-
-      # keep only letters
-      found <- suppressWarnings(as.ab(gsub("[^A-Z]", "", x[i], perl = TRUE), initial_search = FALSE))
-      if (!is.na(found)) {
-        x_new[i] <- note_if_more_than_one_found(found, i, from_text)
-        next
-      }
-
-      # try from a bigger text, like from a health care record, see ?ab_from_text
-      # already calculated above if flag_multiple_results = TRUE
-      if (flag_multiple_results == TRUE) {
-        found <- from_text[1L]
+      if (!is.null(language) && language != "en") {
+        ab_df$trans <- generalise_antibiotic_name(translate_AMR(ab_df$name, language = language))
+        ab_df$lev_trans <- as.double(utils::adist(x[i], ab_df$trans,
+          ignore.case = FALSE,
+          fixed = TRUE,
+          costs = c(insertions = 1, deletions = 1, substitutions = 2),
+          counts = FALSE
+        ))
       } else {
-        found <- tryCatch(suppressWarnings(ab_from_text(x[i], initial_search = FALSE, translate_ab = FALSE)[[1]][1L]),
-          error = function(e) NA_character_
-        )
-      }
-      if (!is.na(found)) {
-        x_new[i] <- note_if_more_than_one_found(found, i, from_text)
-        next
+        ab_df$lev_trans <- ab_df$lev_name
       }
 
-      # first 5 except for cephalosporins, then first 7 (those cephalosporins all start quite the same!)
-      found <- suppressWarnings(as.ab(substr(x[i], 1, 5), initial_search = FALSE))
-      if (!is.na(found) && ab_group(found, initial_search = FALSE) %unlike% "cephalosporins") {
-        x_new[i] <- note_if_more_than_one_found(found, i, from_text)
+      if (any(ab_df$lev_name < 5, na.rm = TRUE)) {
+        x_new[i] <- ab_df$ab[order(ab_df$lev_name)][1]
+        x_uncertain <- c(x_uncertain, x_bak[x[i] == x_bak_clean][1])
         next
-      }
-      found <- suppressWarnings(as.ab(substr(x[i], 1, 7), initial_search = FALSE))
-      if (!is.na(found)) {
-        x_new[i] <- note_if_more_than_one_found(found, i, from_text)
+      } else if (any(ab_df$lev_trans < 5, na.rm = TRUE)) {
+        x_new[i] <- ab_df$ab[order(ab_df$lev_trans)][1]
+        x_uncertain <- c(x_uncertain, x_bak[x[i] == x_bak_clean][1])
         next
-      }
-
-      # make all consonants facultative
-      search_str <- gsub("([BCDFGHJKLMNPQRSTVWXZ])", "\\1*", x[i], perl = TRUE)
-      found <- suppressWarnings(as.ab(search_str, initial_search = FALSE, already_regex = TRUE))
-      # keep at least 4 normal characters
-      if (nchar(gsub(".\\*", "", search_str, perl = TRUE)) < 4) {
-        found <- NA
-      }
-      if (!is.na(found)) {
-        x_new[i] <- note_if_more_than_one_found(found, i, from_text)
+      } else if (any(ab_df$lev_syn < 5, na.rm = TRUE)) {
+        x_new[i] <- ab_df$ab[order(ab_df$lev_syn)][1]
+        x_uncertain <- c(x_uncertain, x_bak[x[i] == x_bak_clean][1])
         next
-      }
-
-      # make all vowels facultative
-      search_str <- gsub("([AEIOUY])", "\\1*", x[i], perl = TRUE)
-      found <- suppressWarnings(as.ab(search_str, initial_search = FALSE, already_regex = TRUE))
-      # keep at least 5 normal characters
-      if (nchar(gsub(".\\*", "", search_str, perl = TRUE)) < 5) {
-        found <- NA
-      }
-      if (!is.na(found)) {
-        x_new[i] <- note_if_more_than_one_found(found, i, from_text)
-        next
-      }
-
-      # allow misspelling of vowels
-      x_spelling <- gsub("A+", "[AEIOU]+", x_spelling, fixed = TRUE)
-      x_spelling <- gsub("E+", "[AEIOU]+", x_spelling, fixed = TRUE)
-      x_spelling <- gsub("I+", "[AEIOU]+", x_spelling, fixed = TRUE)
-      x_spelling <- gsub("O+", "[AEIOU]+", x_spelling, fixed = TRUE)
-      x_spelling <- gsub("U+", "[AEIOU]+", x_spelling, fixed = TRUE)
-      found <- suppressWarnings(as.ab(x_spelling, initial_search = FALSE, already_regex = TRUE))
-      if (!is.na(found)) {
-        x_new[i] <- note_if_more_than_one_found(found, i, from_text)
-        next
-      }
-
-      # try with switched character, like "mreopenem"
-      for (j in seq_len(nchar(x[i]))) {
-        x_switched <- paste0(
-          # beginning part:
-          substr(x[i], 1, j - 1),
-          # here is the switching of 2 characters:
-          substr(x[i], j + 1, j + 1),
-          substr(x[i], j, j),
-          # ending part:
-          substr(x[i], j + 2, nchar(x[i]))
-        )
-        found <- suppressWarnings(as.ab(x_switched, initial_search = FALSE))
-        if (!is.na(found)) {
-          break
+      } else {
+        # then just take name if Levensthein is max 100% of length of name
+        ab_df$lev_len_ratio <- ab_df$lev_name / ab_df$length_name
+        if (any(ab_df$lev_len_ratio < 1)) {
+          ab_df <- ab_df[ab_df$lev_len_ratio < 1, , drop = FALSE]
+          x_new[i] <- ab_df$ab[order(ab_df$lev_name)][1]
+          x_uncertain <- c(x_uncertain, x_bak[x[i] == x_bak_clean][1])
+          next
         }
       }
-      if (!is.na(found)) {
-        x_new[i] <- found[1L]
-        next
-      }
-    } # end of initial_search = TRUE
+    }
 
-    # not found
+    # nothing found
     x_unknown <- c(x_unknown, x_bak[x[i] == x_bak_clean][1])
   }
 
-  if (isTRUE(initial_search) && sum(already_known) < length(x)) {
+  if (sum(already_known) < length(x)) {
     close(progress)
   }
 
   # save to package env to save time for next time
-  if (isTRUE(initial_search)) {
-    AMR_env$ab_previously_coerced <- AMR_env$ab_previously_coerced[which(!AMR_env$ab_previously_coerced$x %in% x), , drop = FALSE]
-    AMR_env$ab_previously_coerced <- unique(rbind_AMR(
-      AMR_env$ab_previously_coerced,
-      data.frame(
-        x = x,
-        ab = x_new,
-        x_bak = x_bak[match(x, x_bak_clean)],
-        stringsAsFactors = FALSE
-      )
-    ))
-  }
+  AMR_env$ab_previously_coerced <- AMR_env$ab_previously_coerced[which(!AMR_env$ab_previously_coerced$x %in% x), , drop = FALSE]
+  AMR_env$ab_previously_coerced <- unique(rbind_AMR(
+    AMR_env$ab_previously_coerced,
+    data.frame(
+      x = x,
+      ab = x_new,
+      x_bak = x_bak[match(x, x_bak_clean)],
+      stringsAsFactors = FALSE
+    )
+  ))
 
   # take failed ATC codes apart from rest
   if (length(x_unknown_ATCs) > 0 && fast_mode == FALSE) {
     warning_(
-      "in `as.ab()`: these ATC codes are not (yet) in the antibiotics data set: ",
+      "in `as.ab()`: these ATC codes are not (yet) in the antimicrobials data set: ",
       vector_and(x_unknown_ATCs), "."
     )
   }
+
+  # Throw note about uncertainties
   x_unknown <- x_unknown[!x_unknown %in% x_unknown_ATCs]
   x_unknown <- c(
     x_unknown,
     AMR_env$ab_previously_coerced$x_bak[which(AMR_env$ab_previously_coerced$x %in% x & is.na(AMR_env$ab_previously_coerced$ab))]
   )
+  x_unknown <- x_unknown[!x_unknown %in% c("", NA)]
   if (length(x_unknown) > 0 && fast_mode == FALSE) {
     warning_(
       "in `as.ab()`: these values could not be coerced to a valid antimicrobial ID: ",
@@ -525,6 +452,29 @@ as.ab <- function(x, flag_multiple_results = TRUE, info = interactive(), ...) {
     )
   }
 
+  # Throw note about uncertainties
+  if (isTRUE(info) && length(x_uncertain) > 0 && fast_mode == FALSE) {
+    x_uncertain <- unique(x_uncertain)
+    if (message_not_thrown_before("as.ab", "uncertainties", x_bak)) {
+      if (length(x_uncertain) <= 3) {
+        examples <- vector_and(
+          paste0(
+            '"', x_uncertain, '" (assumed ',
+            ab_name(AMR_env$ab_previously_coerced$ab[which(AMR_env$ab_previously_coerced$x_bak %in% x_uncertain)], language = NULL, tolower = TRUE),
+            ", ", AMR_env$ab_previously_coerced$ab[which(AMR_env$ab_previously_coerced$x_bak %in% x_uncertain)], ")"
+          ),
+          quotes = FALSE
+        )
+      } else {
+        examples <- paste0(nr2char(length(x_uncertain)), " antimicrobials")
+      }
+      message_(
+        "Antimicrobial translation was uncertain for ", examples,
+        ". If required, use `add_custom_antimicrobials()` to add custom entries."
+      )
+    }
+  }
+
   x_result <- x_new[match(x_bak_clean, x)]
   if (length(x_result) == 0) {
     x_result <- NA_character_
@@ -541,21 +491,37 @@ is.ab <- function(x) {
   inherits(x, "ab")
 }
 
-# will be exported using s3_register() in R/zzz.R
+#' @rdname as.ab
+#' @export
+ab_reset_session <- function() {
+  if (NROW(AMR_env$ab_previously_coerced) > 0) {
+    message_("Reset ", nr2char(NROW(AMR_env$ab_previously_coerced)), " previously matched input value", ifelse(NROW(AMR_env$ab_previously_coerced) > 1, "s", ""), ".")
+    AMR_env$ab_previously_coerced <- AMR_env$ab_previously_coerced[0, , drop = FALSE]
+    AMR_env$mo_uncertainties <- AMR_env$mo_uncertainties[0, , drop = FALSE]
+  } else {
+    message_("No previously matched input values to reset.")
+  }
+}
+
+# this prevents the requirement for putting the dependency in Imports:
+#' @rawNamespace if(getRversion() >= "3.0.0") S3method(pillar::pillar_shaft, ab)
 pillar_shaft.ab <- function(x, ...) {
   out <- trimws(format(x))
   out[is.na(x)] <- font_na(NA)
-  
+
   # add the names to the drugs as mouse-over!
   if (tryCatch(isTRUE(getExportedValue("ansi_has_hyperlink_support", ns = asNamespace("cli"))()), error = function(e) FALSE)) {
-    out[!is.na(x)] <- font_url(url = paste0(x[!is.na(x)], ": ", ab_name(x[!is.na(x)])),
-                               txt = out[!is.na(x)])
+    out[!is.na(x)] <- font_url(
+      url = paste0(x[!is.na(x)], ": ", ab_name(x[!is.na(x)])),
+      txt = out[!is.na(x)]
+    )
   }
-  
+
   create_pillar_column(out, align = "left", min_width = 4)
 }
 
-# will be exported using s3_register() in R/zzz.R
+# this prevents the requirement for putting the dependency in Imports:
+#' @rawNamespace if(getRversion() >= "3.0.0") S3method(pillar::type_sum, ab)
 type_sum.ab <- function(x, ...) {
   "ab"
 }
@@ -564,6 +530,17 @@ type_sum.ab <- function(x, ...) {
 #' @export
 #' @noRd
 print.ab <- function(x, ...) {
+  if (!is.null(attributes(x)$amr_selector)) {
+    function_name <- attributes(x)$amr_selector
+    message_(
+      "This 'ab' vector was retrieved using `", function_name, "()`, which should normally be used inside a `dplyr` verb or `data.frame` call, e.g.:\n",
+      "  ", AMR_env$bullet_icon, " your_data %>% select(", function_name, "())\n",
+      "  ", AMR_env$bullet_icon, " your_data %>% select(column_a, column_b, ", function_name, "())\n",
+      "  ", AMR_env$bullet_icon, " your_data %>% filter(any(", function_name, "() == \"R\"))\n",
+      "  ", AMR_env$bullet_icon, " your_data[, ", function_name, "()]\n",
+      "  ", AMR_env$bullet_icon, " your_data[, c(\"column_a\", \"column_b\", ", function_name, "())]"
+    )
+  }
   cat("Class 'ab'\n")
   print(as.character(x), quote = FALSE)
 }
@@ -639,25 +616,47 @@ rep.ab <- function(x, ...) {
   y
 }
 
+#' @method + ab
+#' @export
+#' @noRd
+`+.ab` <- function(e1, e2) {
+  # this does not return ab class, it should just allow console usage of e.g., carbapenems() + c("", aminoglycosides())
+  out <- as.character(outer(e1, e2, paste, sep = " + "))
+  out <- gsub(" [+] $", "", out)
+  out
+}
+
 generalise_antibiotic_name <- function(x) {
   x <- toupper(x)
   # remove suffices
   x <- gsub("_(MIC|RSI|SIR|DIS[CK])$", "", x, perl = TRUE)
   # remove disk concentrations, like LVX_NM -> LVX
   x <- gsub("_[A-Z]{2}[0-9_.]{0,3}$", "", x, perl = TRUE)
-  # remove part between brackets if that's followed by another string
-  x <- gsub("(.*)+ [(].*[)]", "\\1", x)
   # keep only max 1 space
   x <- trimws2(gsub(" +", " ", x, perl = TRUE))
   # non-character, space or number should be a slash
-  x <- gsub("[^A-Z0-9 -]", "/", x, perl = TRUE)
-  # spaces around non-characters must be removed: amox + clav -> amox/clav
+  x <- gsub("[^A-Z0-9 -)(]", "/", x, perl = TRUE)
+  # correct for 'high level' antibiotics
+  x <- trimws(gsub("([^A-Z0-9/ -]+)?(HIGH(.?LE?VE?L)?|[^A-Z0-9/]H[^A-Z0-9]?L)([^A-Z0-9 -]+)?", "-HIGH", x, perl = TRUE))
+  x <- trimws(gsub("^(-HIGH)(.*)", "\\2\\1", x, perl = TRUE))
+  # remove part between brackets if that's followed by another string
+  x <- gsub("(.*)+ [(].*[)]", "\\1", x)
+  # spaces around non-characters must be removed: amox + clav -> amox clav
   x <- gsub("(.*[A-Z0-9]) ([^A-Z0-9].*)", "\\1\\2", x, perl = TRUE)
   x <- gsub("(.*[^A-Z0-9]) ([A-Z0-9].*)", "\\1\\2", x, perl = TRUE)
+  # rewrite ph to f, and th to t
+  x <- gsub("PH", "F", x, perl = TRUE)
+  x <- gsub("TH", "T", x, perl = TRUE)
   # remove hyphen after a starting "co"
   x <- gsub("^CO-", "CO", x, perl = TRUE)
   # replace operators with a space
   x <- gsub("(/| AND | WITH | W/|[+]|[-])+", " ", x, perl = TRUE)
+  # replace more than 1 space
+  x <- trimws(gsub(" +", " ", x, perl = TRUE))
+  # remove last couple of words if they numbers or units
+  x <- gsub("( ([0-9]{3,}|U?M?C?G|L))+$", "", x, perl = TRUE)
+  # move HIGH to end
+  x <- trimws(gsub("(.*) HIGH(.*)", "\\1\\2 HIGH", x, perl = TRUE))
   x
 }
 
@@ -669,11 +668,38 @@ get_translate_ab <- function(translate_ab) {
     return(FALSE)
   } else {
     translate_ab <- tolower(translate_ab)
-    stop_ifnot(translate_ab %in% colnames(AMR::antibiotics),
-      "invalid value for 'translate_ab', this must be a column name of the antibiotics data set\n",
-      "or TRUE (equals 'name') or FALSE to not translate at all.",
+    stop_ifnot(translate_ab %in% colnames(AMR::antimicrobials),
+      "invalid value for 'translate_ab', this must be a column name of the `antimicrobials` data set\n",
+      "or `TRUE` (equals 'name') or `FALSE` to not translate at all.",
       call = FALSE
     )
     translate_ab
   }
 }
+
+create_AB_AV_lookup <- function(df) {
+  new_df <- df
+  new_df$generalised_name <- generalise_antibiotic_name(new_df$name)
+  new_df$generalised_synonyms <- lapply(new_df$synonyms, generalise_antibiotic_name)
+  if ("abbreviations" %in% colnames(df)) {
+    new_df$generalised_abbreviations <- lapply(new_df$abbreviations, generalise_antibiotic_name)
+  }
+  new_df$generalised_loinc <- lapply(new_df$loinc, generalise_antibiotic_name)
+  new_df$generalised_all <- unname(lapply(
+    as.list(as.data.frame(
+      t(new_df[,
+        c(
+          colnames(new_df)[colnames(new_df) %in% c("ab", "av", "atc", "cid", "name")],
+          colnames(new_df)[colnames(new_df) %like% "generalised"]
+        ),
+        drop = FALSE
+      ]),
+      stringsAsFactors = FALSE
+    )),
+    function(x) {
+      x <- generalise_antibiotic_name(unname(unlist(x)))
+      x[x != ""]
+    }
+  ))
+  new_df[, colnames(new_df)[colnames(new_df) %like% "^generalised"]]
+}
