@@ -6,9 +6,9 @@
 # https://github.com/msberends/AMR                                     #
 #                                                                      #
 # PLEASE CITE THIS SOFTWARE AS:                                        #
-# Berends MS, Luz CF, Friedrich AW, Sinha BNM, Albers CJ, Glasner C    #
-# (2022). AMR: An R Package for Working with Antimicrobial Resistance  #
-# Data. Journal of Statistical Software, 104(3), 1-31.                 #
+# Berends MS, Luz CF, Friedrich AW, et al. (2022).                     #
+# AMR: An R Package for Working with Antimicrobial Resistance Data.    #
+# Journal of Statistical Software, 104(3), 1-31.                       #
 # https://doi.org/10.18637/jss.v104.i03                                #
 #                                                                      #
 # Developed at the University of Groningen and the University Medical  #
@@ -24,33 +24,35 @@
 # useful, but it comes WITHOUT ANY WARRANTY OR LIABILITY.              #
 #                                                                      #
 # Visit our website for the full manual and a complete tutorial about  #
-# how to conduct AMR data analysis: https://msberends.github.io/AMR/   #
+# how to conduct AMR data analysis: https://amr-for-r.org              #
 # ==================================================================== #
 
 #' Determine First Isolates
 #'
 #' Determine first isolates of all microorganisms of every patient per episode and (if needed) per specimen type. These functions support all four methods as summarised by Hindler *et al.* in 2007 (\doi{10.1086/511864}). To determine patient episodes not necessarily based on microorganisms, use [is_new_episode()] that also supports grouping with the `dplyr` package.
-#' @param x a [data.frame] containing isolates. Can be left blank for automatic determination, see *Examples*.
-#' @param col_date column name of the result date (or date that is was received on the lab) - the default is the first column with a date class
-#' @param col_patient_id column name of the unique IDs of the patients - the default is the first column that starts with 'patient' or 'patid' (case insensitive)
-#' @param col_mo column name of the names or codes of the microorganisms (see [as.mo()]) - the default is the first column of class [`mo`]. Values will be coerced using [as.mo()].
-#' @param col_testcode column name of the test codes. Use `col_testcode = NULL` to **not** exclude certain test codes (such as test codes for screening). In that case `testcodes_exclude` will be ignored.
-#' @param col_specimen column name of the specimen type or group
-#' @param col_icu column name of the logicals (`TRUE`/`FALSE`) whether a ward or department is an Intensive Care Unit (ICU). This can also be a [logical] vector with the same length as rows in `x`.
+#' @param x A [data.frame] containing isolates. Can be left blank for automatic determination, see *Examples*.
+#' @param col_date Column name of the result date (or date that is was received on the lab) - the default is the first column with a date class.
+#' @param col_patient_id Column name of the unique IDs of the patients - the default is the first column that starts with 'patient' or 'patid' (case insensitive).
+#' @param col_mo Column name of the names or codes of the microorganisms (see [as.mo()]) - the default is the first column of class [`mo`]. Values will be coerced using [as.mo()].
+#' @param col_testcode Column name of the test codes. Use `col_testcode = NULL` to **not** exclude certain test codes (such as test codes for screening). In that case `testcodes_exclude` will be ignored.
+#' @param col_specimen Column name of the specimen type or group.
+#' @param col_icu Column name of the logicals (`TRUE`/`FALSE`) whether a ward or department is an Intensive Care Unit (ICU). This can also be a [logical] vector with the same length as rows in `x`.
 #' @param col_keyantimicrobials (only useful when `method = "phenotype-based"`) column name of the key antimicrobials to determine first isolates, see [key_antimicrobials()]. The default is the first column that starts with 'key' followed by 'ab' or 'antibiotics' or 'antimicrobials' (case insensitive). Use `col_keyantimicrobials = FALSE` to prevent this. Can also be the output of [key_antimicrobials()].
-#' @param episode_days episode in days after which a genus/species combination will be determined as 'first isolate' again. The default of 365 days is based on the guideline by CLSI, see *Source*.
-#' @param testcodes_exclude a [character] vector with test codes that should be excluded (case-insensitive)
-#' @param icu_exclude a [logical] to indicate whether ICU isolates should be excluded (rows with value `TRUE` in the column set with `col_icu`)
-#' @param specimen_group value in the column set with `col_specimen` to filter on
-#' @param type type to determine weighed isolates; can be `"keyantimicrobials"` or `"points"`, see *Details*
-#' @param method the method to apply, either `"phenotype-based"`, `"episode-based"`, `"patient-based"` or `"isolate-based"` (can be abbreviated), see *Details*. The default is `"phenotype-based"` if antimicrobial test results are present in the data, and `"episode-based"` otherwise.
-#' @param ignore_I [logical] to indicate whether antibiotic interpretations with `"I"` will be ignored when `type = "keyantimicrobials"`, see *Details*
-#' @param points_threshold minimum number of points to require before differences in the antibiogram will lead to inclusion of an isolate when `type = "points"`, see *Details*
-#' @param info a [logical] to indicate info should be printed - the default is `TRUE` only in interactive mode
-#' @param include_unknown a [logical] to indicate whether 'unknown' microorganisms should be included too, i.e. microbial code `"UNKNOWN"`, which defaults to `FALSE`. For WHONET users, this means that all records with organism code `"con"` (*contamination*) will be excluded at default. Isolates with a microbial ID of `NA` will always be excluded as first isolate.
-#' @param include_untested_sir a [logical] to indicate whether also rows without antibiotic results are still eligible for becoming a first isolate. Use `include_untested_sir = FALSE` to always return `FALSE` for such rows. This checks the data set for columns of class `sir` and consequently requires transforming columns with antibiotic results using [as.sir()] first.
-#' @param ... arguments passed on to [first_isolate()] when using [filter_first_isolate()], otherwise arguments passed on to [key_antimicrobials()] (such as `universal`, `gram_negative`, `gram_positive`)
+#' @param episode_days Episode in days after which a genus/species combination will be determined as 'first isolate' again. The default of 365 days is based on the guideline by CLSI, see *Source*.
+#' @param testcodes_exclude A [character] vector with test codes that should be excluded (case-insensitive).
+#' @param icu_exclude A [logical] to indicate whether ICU isolates should be excluded (rows with value `TRUE` in the column set with `col_icu`).
+#' @param specimen_group Value in the column set with `col_specimen` to filter on.
+#' @param type Type to determine weighed isolates; can be `"keyantimicrobials"` or `"points"`, see *Details*.
+#' @param method The method to apply, either `"phenotype-based"`, `"episode-based"`, `"patient-based"` or `"isolate-based"` (can be abbreviated), see *Details*. The default is `"phenotype-based"` if antimicrobial test results are present in the data, and `"episode-based"` otherwise.
+#' @param ignore_I [logical] to indicate whether antibiotic interpretations with `"I"` will be ignored when `type = "keyantimicrobials"`, see *Details*.
+#' @param points_threshold Minimum number of points to require before differences in the antibiogram will lead to inclusion of an isolate when `type = "points"`, see *Details*.
+#' @param info A [logical] to indicate info should be printed - the default is `TRUE` only in interactive mode.
+#' @param include_unknown A [logical] to indicate whether 'unknown' microorganisms should be included too, i.e. microbial code `"UNKNOWN"`, which defaults to `FALSE`. For WHONET users, this means that all records with organism code `"con"` (*contamination*) will be excluded at default. Isolates with a microbial ID of `NA` will always be excluded as first isolate.
+#' @param include_untested_sir A [logical] to indicate whether also rows without antibiotic results are still eligible for becoming a first isolate. Use `include_untested_sir = FALSE` to always return `FALSE` for such rows. This checks the data set for columns of class `sir` and consequently requires transforming columns with antibiotic results using [as.sir()] first.
+#' @param ... Arguments passed on to [first_isolate()] when using [filter_first_isolate()], otherwise arguments passed on to [key_antimicrobials()] (such as `universal`, `gram_negative`, `gram_positive`).
 #' @details
+#' The methodology implemented in these functions is strictly based on the recommendations outlined in [CLSI Guideline M39](https://clsi.org/standards/products/microbiology/documents/m39) and the research overview by Hindler *et al.* (2007, \doi{10.1086/511864}).
+#'
 #' To conduct epidemiological analyses on antimicrobial resistance data, only so-called first isolates should be included to prevent overestimation and underestimation of antimicrobial resistance. Different methods can be used to do so, see below.
 #'
 #' These functions are context-aware. This means that the `x` argument can be left blank if used inside a [data.frame] call, see *Examples*.
@@ -61,7 +63,7 @@
 #'
 #' ### Different methods
 #'
-#' According to Hindler *et al.* (2007, \doi{10.1086/511864}), there are different methods (algorithms) to select first isolates with increasing reliability: isolate-based, patient-based, episode-based and phenotype-based. All methods select on a combination of the taxonomic genus and species (not subspecies).
+#' According to previously-mentioned sources, there are different methods (algorithms) to select first isolates with increasing reliability: isolate-based, patient-based, episode-based and phenotype-based. All methods select on a combination of the taxonomic genus and species (not subspecies).
 #'
 #' All mentioned methods are covered in the [first_isolate()] function:
 #'
@@ -93,11 +95,11 @@
 #'
 #' ### Patient-based
 #'
-#' To include every genus-species combination per patient once, set the `episode_days` to `Inf`. Although often inappropriate, this method makes sure that no duplicate isolates are selected from the same patient. In a large longitudinal data set, this could mean that isolates are *excluded* that were found years after the initial isolate.
+#' To include every genus-species combination per patient once, set the `episode_days` to `Inf`. This method makes sure that no duplicate isolates are selected from the same patient. This method is preferred to e.g. identify the first MRSA finding of each patient to determine the incidence. Conversely, in a large longitudinal data set, this could mean that isolates are *excluded* that were found years after the initial isolate.
 #'
 #' ### Episode-based
 #'
-#' To include every genus-species combination per patient episode once, set the `episode_days` to a sensible number of days. Depending on the type of analysis, this could be 14, 30, 60 or 365. Short episodes are common for analysing specific hospital or ward data, long episodes are common for analysing regional and national data.
+#' To include every genus-species combination per patient episode once, set the `episode_days` to a sensible number of days. Depending on the type of analysis, this could be 14, 30, 60 or 365. Short episodes are common for analysing specific hospital or ward data or ICU cases, long episodes are common for analysing regional and national data.
 #'
 #' This is the most common method to correct for duplicate isolates. Patients are categorised into episodes based on their ID and dates (e.g., the date of specimen receipt or laboratory result). While this is a common method, it does not take into account antimicrobial test results. This means that e.g. a methicillin-resistant *Staphylococcus aureus* (MRSA) isolate cannot be differentiated from a wildtype *Staphylococcus aureus* isolate.
 #'
@@ -124,7 +126,7 @@
 #' @seealso [key_antimicrobials()]
 #' @export
 #' @return A [logical] vector
-#' @source Methodology of this function is strictly based on:
+#' @source Methodology of these functions is strictly based on:
 #'
 #' - **M39 Analysis and Presentation of Cumulative Antimicrobial Susceptibility Test Data, 5th Edition**, 2022, *Clinical and Laboratory Standards Institute (CLSI)*. <https://clsi.org/standards/products/microbiology/documents/m39/>.
 #'
@@ -227,10 +229,6 @@ first_isolate <- function(x = NULL,
   meet_criteria(points_threshold, allow_class = c("numeric", "integer"), has_length = 1, is_positive = TRUE, is_finite = TRUE)
   meet_criteria(info, allow_class = "logical", has_length = 1)
   meet_criteria(include_unknown, allow_class = "logical", has_length = 1)
-  if ("include_untested_rsi" %in% names(list(...))) {
-    deprecation_warning("include_untested_rsi", "include_untested_sir", is_function = FALSE)
-    include_untested_sir <- list(...)$include_untested_rsi
-  }
   meet_criteria(include_untested_sir, allow_class = "logical", has_length = 1)
 
   # remove data.table, grouping from tibbles, etc.
@@ -240,7 +238,7 @@ first_isolate <- function(x = NULL,
     FUN.VALUE = logical(1),
     X = x,
     # check only first 10,000 rows
-    FUN = function(x) any(as.character(x[1:10000]) %in% c("S", "I", "R"), na.rm = TRUE),
+    FUN = function(x) any(as.character(x[1:10000]) %in% c("S", "SDD", "I", "R", "NI"), na.rm = TRUE),
     USE.NAMES = FALSE
   ))
   if (method == "phenotype-based" && !any_col_contains_sir) {
@@ -366,7 +364,7 @@ first_isolate <- function(x = NULL,
     specimen_group <- NULL
   }
 
-  # filter on specimen group and keyantibiotics when they are filled in
+  # filter on specimen group and keyantimicrobials when they are filled in
   if (!is.null(specimen_group)) {
     check_columns_existance(col_specimen, x)
     if (isTRUE(info) && message_not_thrown_before("first_isolate", "excludingspecimen")) {
@@ -468,7 +466,7 @@ first_isolate <- function(x = NULL,
   x$other_pat_or_mo <- !(x$newvar_patient_id == pm_lag(x$newvar_patient_id) & x$newvar_genus_species == pm_lag(x$newvar_genus_species))
 
   x$newvar_episode_group <- paste(x$newvar_patient_id, x$newvar_genus_species)
-  
+
   x$more_than_episode_ago <- unlist(
     lapply(
       split(
@@ -481,7 +479,7 @@ first_isolate <- function(x = NULL,
     ),
     use.names = FALSE
   )
-  
+
   if (!is.null(col_keyantimicrobials)) {
     # using phenotypes
     x$different_antibiogram <- !unlist(
@@ -500,15 +498,15 @@ first_isolate <- function(x = NULL,
   } else {
     x$different_antibiogram <- FALSE
   }
-  
+
   x$newvar_first_isolate <- x$newvar_row_index_sorted >= row.start &
     x$newvar_row_index_sorted <= row.end &
     x$newvar_genus_species != "" &
     (x$other_pat_or_mo | x$more_than_episode_ago | x$different_antibiogram)
-  
+
   decimal.mark <- getOption("OutDec")
   big.mark <- ifelse(decimal.mark != ",", ",", " ")
-  
+
   # first one as TRUE
   x[row.start, "newvar_first_isolate"] <- TRUE
   # no tests that should be included, or ICU
@@ -519,7 +517,8 @@ first_isolate <- function(x = NULL,
     if (icu_exclude == TRUE) {
       if (isTRUE(info)) {
         message_("Excluding ", format(sum(x$newvar_is_icu, na.rm = TRUE), decimal.mark = decimal.mark, big.mark = big.mark), " isolates from ICU.",
-                 add_fn = font_red)
+          add_fn = font_red
+        )
       }
       x[which(x$newvar_is_icu), "newvar_first_isolate"] <- FALSE
     } else if (isTRUE(info)) {
@@ -674,21 +673,28 @@ duplicated_antibiogram <- function(antibiogram, points_threshold, ignore_I, type
     # fast return, only 1 isolate
     return(FALSE)
   }
+  # first sort on data availability - count the dots and order that ascending so that highest availability of SIR is on top
+  number_dots <- vapply(
+    FUN.VALUE = integer(1),
+    antibiogram,
+    function(x) sum(strsplit(x, "", fixed = TRUE)[[1]] == "."),
+    USE.NAMES = FALSE
+  )
+  new_order <- order(number_dots, antibiogram)
+  antibiogram.bak <- antibiogram
+  antibiogram <- antibiogram[new_order]
+
   out <- rep(NA, length(antibiogram))
   out[1] <- FALSE
   out[2] <- antimicrobials_equal(antibiogram[1], antibiogram[2],
-                                 ignore_I = ignore_I, points_threshold = points_threshold,
-                                 type = type)
+    ignore_I = ignore_I, points_threshold = points_threshold,
+    type = type
+  )
   if (length(antibiogram) == 2) {
     # fast return, no further check required
     return(out)
   }
-  
-  # sort after the second one (since we already determined AB equality of the first two)
-  original_sort <- c(1, 2, rank(antibiogram[3:length(antibiogram)]) + 2)
-  antibiogram.bak <- antibiogram
-  antibiogram <- c(antibiogram[1:2], sort(antibiogram[3:length(antibiogram)]))
-  
+
   # we can skip the duplicates - they are never unique antibiograms of course
   duplicates <- duplicated(antibiogram)
   out[3:length(out)][duplicates[3:length(out)] == TRUE] <- TRUE
@@ -696,18 +702,25 @@ duplicated_antibiogram <- function(antibiogram, points_threshold, ignore_I, type
     # fast return, no further check required
     return(c(out[1:2], rep(TRUE, length(out) - 2)))
   }
-  
+
   for (na in antibiogram[is.na(out)]) {
     # check if this antibiogram has any change with other antibiograms
     out[which(antibiogram == na)] <- all(
-      vapply(FUN.VALUE = logical(1),
-             antibiogram[!is.na(out) & antibiogram != na],
-             function(y) antimicrobials_equal(y = y, z = na,
-                                              ignore_I = ignore_I, points_threshold = points_threshold,
-                                              type = type)))
+      vapply(
+        FUN.VALUE = logical(1),
+        antibiogram[!is.na(out) & antibiogram != na],
+        function(y) {
+          antimicrobials_equal(
+            y = y, z = na,
+            ignore_I = ignore_I, points_threshold = points_threshold,
+            type = type
+          )
+        }
+      )
+    )
   }
-  
-  out <- out[original_sort]
+
+  out <- out[order(new_order)]
   # rerun duplicated again
   duplicates <- duplicated(antibiogram.bak)
   out[duplicates == TRUE] <- TRUE
