@@ -6,9 +6,9 @@
 # https://github.com/msberends/AMR                                     #
 #                                                                      #
 # PLEASE CITE THIS SOFTWARE AS:                                        #
-# Berends MS, Luz CF, Friedrich AW, Sinha BNM, Albers CJ, Glasner C    #
-# (2022). AMR: An R Package for Working with Antimicrobial Resistance  #
-# Data. Journal of Statistical Software, 104(3), 1-31.                 #
+# Berends MS, Luz CF, Friedrich AW, et al. (2022).                     #
+# AMR: An R Package for Working with Antimicrobial Resistance Data.    #
+# Journal of Statistical Software, 104(3), 1-31.                       #
 # https://doi.org/10.18637/jss.v104.i03                                #
 #                                                                      #
 # Developed at the University of Groningen and the University Medical  #
@@ -24,15 +24,15 @@
 # useful, but it comes WITHOUT ANY WARRANTY OR LIABILITY.              #
 #                                                                      #
 # Visit our website for the full manual and a complete tutorial about  #
-# how to conduct AMR data analysis: https://msberends.github.io/AMR/   #
+# how to conduct AMR data analysis: https://amr-for-r.org              #
 # ==================================================================== #
 
 #' Calculate the Mean AMR Distance
 #'
 #' Calculates a normalised mean for antimicrobial resistance between multiple observations, to help to identify similar isolates without comparing antibiograms by hand.
-#' @param x a vector of class [sir][as.sir()], [mic][as.mic()] or [disk][as.disk()], or a [data.frame] containing columns of any of these classes
-#' @param ... variables to select (supports [tidyselect language][tidyselect::language] such as `column1:column4` and `where(is.mic)`, and can thus also be [antibiotic selectors][ab_selector()]
-#' @param combine_SI 	a [logical] to indicate whether all values of S and I must be merged into one, so the input only consists of S+I vs. R (susceptible vs. resistant) - the default is `TRUE`
+#' @param x A vector of class [sir][as.sir()], [mic][as.mic()] or [disk][as.disk()], or a [data.frame] containing columns of any of these classes.
+#' @param ... Variables to select. Supports [tidyselect language][tidyselect::language] (such as `column1:column4` and `where(is.mic)`), and can thus also be [antimicrobial selectors][amr_selector()].
+#' @param combine_SI A [logical] to indicate whether all values of S, SDD, and I must be merged into one, so the input only consists of S+I vs. R (susceptible vs. resistant) - the default is `TRUE`.
 #' @details The mean AMR distance is effectively [the Z-score](https://en.wikipedia.org/wiki/Standard_score); a normalised numeric value to compare AMR test results which can help to identify similar isolates, without comparing antibiograms by hand.
 #'
 #' MIC values (see [as.mic()]) are transformed with [log2()] first; their distance is thus calculated as `(log2(x) - mean(log2(x))) / sd(log2(x))`.
@@ -69,7 +69,7 @@
 #' )
 #' y
 #' mean_amr_distance(y)
-#' y$amr_distance <- mean_amr_distance(y, where(is.mic))
+#' y$amr_distance <- mean_amr_distance(y, is.mic(y))
 #' y[order(y$amr_distance), ]
 #'
 #' if (require("dplyr")) {
@@ -118,7 +118,7 @@ mean_amr_distance.disk <- function(x, ...) {
 mean_amr_distance.sir <- function(x, ..., combine_SI = TRUE) {
   meet_criteria(combine_SI, allow_class = "logical", has_length = 1, .call_depth = -1)
   if (isTRUE(combine_SI)) {
-    x[x == "I"] <- "S"
+    x[x %in% c("I", "SDD")] <- "S"
   }
   mean_amr_distance(as.double(x))
 }
@@ -171,12 +171,12 @@ mean_amr_distance.data.frame <- function(x, ..., combine_SI = TRUE) {
 }
 
 #' @rdname mean_amr_distance
-#' @param amr_distance the outcome of [mean_amr_distance()]
-#' @param row an index, such as a row number
+#' @param amr_distance The outcome of [mean_amr_distance()].
+#' @param row An index, such as a row number.
 #' @export
 amr_distance_from_row <- function(amr_distance, row) {
-  meet_criteria(amr_distance, allow_class = c("double", "numeric"), is_finite = TRUE)
-  meet_criteria(row, allow_class = c("logical", "double", "numeric"))
+  meet_criteria(amr_distance, allow_class = "numeric", is_finite = TRUE)
+  meet_criteria(row, allow_class = c("logical", "numeric", "integer"))
   if (is.logical(row)) {
     row <- which(row)
   }
