@@ -6,9 +6,9 @@
 # https://github.com/msberends/AMR                                     #
 #                                                                      #
 # PLEASE CITE THIS SOFTWARE AS:                                        #
-# Berends MS, Luz CF, Friedrich AW, Sinha BNM, Albers CJ, Glasner C    #
-# (2022). AMR: An R Package for Working with Antimicrobial Resistance  #
-# Data. Journal of Statistical Software, 104(3), 1-31.                 #
+# Berends MS, Luz CF, Friedrich AW, et al. (2022).                     #
+# AMR: An R Package for Working with Antimicrobial Resistance Data.    #
+# Journal of Statistical Software, 104(3), 1-31.                       #
 # https://doi.org/10.18637/jss.v104.i03                                #
 #                                                                      #
 # Developed at the University of Groningen and the University Medical  #
@@ -24,7 +24,7 @@
 # useful, but it comes WITHOUT ANY WARRANTY OR LIABILITY.              #
 #                                                                      #
 # Visit our website for the full manual and a complete tutorial about  #
-# how to conduct AMR data analysis: https://msberends.github.io/AMR/   #
+# how to conduct AMR data analysis: https://amr-for-r.org              #
 # ==================================================================== #
 
 #' Calculate Antimicrobial Resistance
@@ -32,23 +32,25 @@
 #' @description These functions can be used to calculate the (co-)resistance or susceptibility of microbial isolates (i.e. percentage of S, SI, I, IR or R). All functions support quasiquotation with pipes, can be used in `summarise()` from the `dplyr` package and also support grouped variables, see *Examples*.
 #'
 #' [resistance()] should be used to calculate resistance, [susceptibility()] should be used to calculate susceptibility.\cr
-#' @param ... one or more vectors (or columns) with antibiotic interpretations. They will be transformed internally with [as.sir()] if needed. Use multiple columns to calculate (the lack of) co-resistance: the probability where one of two drugs have a resistant or susceptible result. See *Examples*.
-#' @param minimum the minimum allowed number of available (tested) isolates. Any isolate count lower than `minimum` will return `NA` with a warning. The default number of `30` isolates is advised by the Clinical and Laboratory Standards Institute (CLSI) as best practice, see *Source*.
-#' @param as_percent a [logical] to indicate whether the output must be returned as a hundred fold with % sign (a character). A value of `0.123456` will then be returned as `"12.3%"`.
-#' @param only_all_tested (for combination therapies, i.e. using more than one variable for `...`): a [logical] to indicate that isolates must be tested for all antibiotics, see section *Combination Therapy* below
-#' @param data a [data.frame] containing columns with class [`sir`] (see [as.sir()])
-#' @param translate_ab a column name of the [antibiotics] data set to translate the antibiotic abbreviations to, using [ab_property()]
+#' @param ... One or more vectors (or columns) with antibiotic interpretations. They will be transformed internally with [as.sir()] if needed. Use multiple columns to calculate (the lack of) co-resistance: the probability where one of two drugs have a resistant or susceptible result. See *Examples*.
+#' @param minimum The minimum allowed number of available (tested) isolates. Any isolate count lower than `minimum` will return `NA` with a warning. The default number of `30` isolates is advised by the Clinical and Laboratory Standards Institute (CLSI) as best practice, see *Source*.
+#' @param as_percent A [logical] to indicate whether the output must be returned as a hundred fold with % sign (a character). A value of `0.123456` will then be returned as `"12.3%"`.
+#' @param only_all_tested (for combination therapies, i.e. using more than one variable for `...`): a [logical] to indicate that isolates must be tested for all antimicrobials, see section *Combination Therapy* below.
+#' @param data A [data.frame] containing columns with class [`sir`] (see [as.sir()]).
+#' @param translate_ab A column name of the [antimicrobials] data set to translate the antibiotic abbreviations to, using [ab_property()].
 #' @inheritParams ab_property
-#' @param combine_SI a [logical] to indicate whether all values of S and I must be merged into one, so the output only consists of S+I vs. R (susceptible vs. resistant) - the default is `TRUE`
-#' @param ab_result antibiotic results to test against, must be one or more values of "S", "I", or "R"
-#' @param confidence_level the confidence level for the returned confidence interval. For the calculation, the number of S or SI isolates, and R isolates are compared with the total number of available isolates with R, S, or I by using [binom.test()], i.e., the Clopper-Pearson method.
-#' @param side the side of the confidence interval to return. The default is `"both"` for a length 2 vector, but can also be (abbreviated as) `"min"`/`"left"`/`"lower"`/`"less"` or `"max"`/`"right"`/`"higher"`/`"greater"`.
-#' @param collapse a [logical] to indicate whether the output values should be 'collapsed', i.e. be merged together into one value, or a character value to use for collapsing
+#' @param combine_SI A [logical] to indicate whether all values of S, SDD, and I must be merged into one, so the output only consists of S+SDD+I vs. R (susceptible vs. resistant) - the default is `TRUE`.
+#' @param ab_result Antibiotic results to test against, must be one or more values of "S", "SDD", "I", or "R".
+#' @param confidence_level The confidence level for the returned confidence interval. For the calculation, the number of S or SI isolates, and R isolates are compared with the total number of available isolates with R, S, or I by using [binom.test()], i.e., the Clopper-Pearson method.
+#' @param side The side of the confidence interval to return. The default is `"both"` for a length 2 vector, but can also be (abbreviated as) `"min"`/`"left"`/`"lower"`/`"less"` or `"max"`/`"right"`/`"higher"`/`"greater"`.
+#' @param collapse A [logical] to indicate whether the output values should be 'collapsed', i.e. be merged together into one value, or a character value to use for collapsing.
 #' @inheritSection as.sir Interpretation of SIR
 #' @details
+#' For a more automated and comprehensive analysis, consider using [antibiogram()] or [wisca()], which streamline many aspects of susceptibility reporting and, importantly, also support WISCA. The functions described here offer a more hands-on, manual approach for greater customisation.
+#'
 #' **Remember that you should filter your data to let it contain only first isolates!** This is needed to exclude duplicates and to reduce selection bias. Use [first_isolate()] to determine them in your data set with one of the four available algorithms.
-#' 
-#' The function [resistance()] is equal to the function [proportion_R()]. The function [susceptibility()] is equal to the function [proportion_SI()].
+#'
+#' The function [resistance()] is equal to the function [proportion_R()]. The function [susceptibility()] is equal to the function [proportion_SI()]. Since AMR v3.0, [proportion_SI()] and [proportion_I()] include dose-dependent susceptibility ('SDD').
 #'
 #' Use [sir_confidence_interval()] to calculate the confidence interval, which relies on [binom.test()], i.e., the Clopper-Pearson method. This function returns a vector of length 2 at default for antimicrobial *resistance*. Change the `side` argument to "left"/"min" or "right"/"max" to return a single value, and change the `ab_result` argument to e.g. `c("S", "I")` to test for antimicrobial *susceptibility*, see Examples.
 #'
@@ -56,25 +58,25 @@
 #'
 #' The function [proportion_df()] takes any variable from `data` that has an [`sir`] class (created with [as.sir()]) and calculates the proportions S, I, and R. It also supports grouped variables. The function [sir_df()] works exactly like [proportion_df()], but adds the number of isolates.
 #' @section Combination Therapy:
-#' When using more than one variable for `...` (= combination therapy), use `only_all_tested` to only count isolates that are tested for all antibiotics/variables that you test them for. See this example for two antibiotics, Drug A and Drug B, about how [susceptibility()] works to calculate the %SI:
+#' When using more than one variable for `...` (= combination therapy), use `only_all_tested` to only count isolates that are tested for all antimicrobials/variables that you test them for. See this example for two antimicrobials, Drug A and Drug B, about how [susceptibility()] works to calculate the %SI:
 #'
 #'
 #' ```
 #' --------------------------------------------------------------------
 #'                     only_all_tested = FALSE  only_all_tested = TRUE
 #'                     -----------------------  -----------------------
-#'  Drug A    Drug B   include as  include as   include as  include as
-#'                     numerator   denominator  numerator   denominator
-#' --------  --------  ----------  -----------  ----------  -----------
-#'  S or I    S or I       X            X            X            X
-#'    R       S or I       X            X            X            X
-#'   <NA>     S or I       X            X            -            -
-#'  S or I      R          X            X            X            X
-#'    R         R          -            X            -            X
-#'   <NA>       R          -            -            -            -
-#'  S or I     <NA>        X            X            -            -
-#'    R        <NA>        -            -            -            -
-#'   <NA>      <NA>        -            -            -            -
+#'  Drug A    Drug B   considered   considered  considered   considered
+#'                     susceptible    tested    susceptible    tested
+#' --------  --------  -----------  ----------  -----------  ----------
+#'  S or I    S or I        X            X           X            X
+#'    R       S or I        X            X           X            X
+#'   <NA>     S or I        X            X           -            -
+#'  S or I      R           X            X           X            X
+#'    R         R           -            X           -            X
+#'   <NA>       R           -            -           -            -
+#'  S or I     <NA>         X            X           -            -
+#'    R        <NA>         -            -           -            -
+#'   <NA>      <NA>         -            -           -            -
 #' --------------------------------------------------------------------
 #' ```
 #'
@@ -151,7 +153,7 @@
 #'     )
 #' }
 #' if (require("dplyr")) {
-#'   # scoped dplyr verbs with antibiotic selectors
+#'   # scoped dplyr verbs with antimicrobial selectors
 #'   # (you could also use across() of course)
 #'   example_isolates %>%
 #'     group_by(ward) %>%
@@ -247,7 +249,7 @@ susceptibility <- function(...,
                            only_all_tested = FALSE) {
   tryCatch(
     sir_calc(...,
-      ab_result = c("S", "I"),
+      ab_result = c("S", "SDD", "I"),
       minimum = minimum,
       as_percent = as_percent,
       only_all_tested = only_all_tested,
@@ -267,7 +269,7 @@ sir_confidence_interval <- function(...,
                                     confidence_level = 0.95,
                                     side = "both",
                                     collapse = FALSE) {
-  meet_criteria(ab_result, allow_class = c("character", "sir"), has_length = c(1, 2, 3), is_in = c("S", "I", "R"))
+  meet_criteria(ab_result, allow_class = c("character", "sir"), has_length = c(1:5), is_in = c("S", "SDD", "I", "R", "NI"))
   meet_criteria(minimum, allow_class = c("numeric", "integer"), has_length = 1, is_positive_or_zero = TRUE, is_finite = TRUE)
   meet_criteria(as_percent, allow_class = "logical", has_length = 1)
   meet_criteria(only_all_tested, allow_class = "logical", has_length = 1)
@@ -285,16 +287,20 @@ sir_confidence_interval <- function(...,
   )
   n <- tryCatch(
     sir_calc(...,
-      ab_result = c("S", "I", "R"),
+      ab_result = c("S", "SDD", "I", "R", "NI"),
       only_all_tested = only_all_tested,
       only_count = TRUE
     ),
     error = function(e) stop_(gsub("in sir_calc(): ", "", e$message, fixed = TRUE), call = -5)
   )
 
-  # this applies the Clopper-Pearson method
-  out <- stats::binom.test(x = x, n = n, conf.level = confidence_level)$conf.int
-  out <- set_clean_class(out, "double")
+  if (x == 0) {
+    out <- c(0, 0)
+  } else {
+    # this applies the Clopper-Pearson method
+    out <- stats::binom.test(x = x, n = n, conf.level = confidence_level)$conf.int
+  }
+  out <- set_clean_class(out, "numeric")
 
   if (side %in% c("left", "l", "lower", "lowest", "less", "min")) {
     out <- out[1]
@@ -302,12 +308,13 @@ sir_confidence_interval <- function(...,
     out <- out[2]
   }
   if (isTRUE(as_percent)) {
-    out <- percentage(out, digits = 1)
+    out <- trimws(percentage(out, digits = 1))
   }
   if (!isFALSE(collapse) && length(out) > 1) {
     if (is.numeric(out)) {
       out <- round(out, digits = 3)
     }
+    # out[is.na(out)] <- 0
     out <- paste(out, collapse = ifelse(isTRUE(collapse), "-", collapse))
   }
 
@@ -323,7 +330,6 @@ sir_confidence_interval <- function(...,
       return(NA_real_)
     }
   }
-
   out
 }
 
@@ -353,7 +359,7 @@ proportion_IR <- function(...,
                           only_all_tested = FALSE) {
   tryCatch(
     sir_calc(...,
-      ab_result = c("I", "R"),
+      ab_result = c("I", "SDD", "R"),
       minimum = minimum,
       as_percent = as_percent,
       only_all_tested = only_all_tested,
@@ -371,7 +377,7 @@ proportion_I <- function(...,
                          only_all_tested = FALSE) {
   tryCatch(
     sir_calc(...,
-      ab_result = "I",
+      ab_result = c("I", "SDD"),
       minimum = minimum,
       as_percent = as_percent,
       only_all_tested = only_all_tested,
@@ -389,7 +395,7 @@ proportion_SI <- function(...,
                           only_all_tested = FALSE) {
   tryCatch(
     sir_calc(...,
-      ab_result = c("S", "I"),
+      ab_result = c("S", "I", "SDD"),
       minimum = minimum,
       as_percent = as_percent,
       only_all_tested = only_all_tested,
