@@ -1,15 +1,19 @@
 # ==================================================================== #
-# TITLE                                                                #
-# Antimicrobial Resistance (AMR) Data Analysis for R                   #
+# TITLE:                                                               #
+# AMR: An R Package for Working with Antimicrobial Resistance Data     #
 #                                                                      #
-# SOURCE                                                               #
+# SOURCE CODE:                                                         #
 # https://github.com/msberends/AMR                                     #
 #                                                                      #
-# LICENCE                                                              #
-# (c) 2018-2021 Berends MS, Luz CF et al.                              #
-# Developed at the University of Groningen, the Netherlands, in        #
-# collaboration with non-profit organisations Certe Medical            #
-# Diagnostics & Advice, and University Medical Center Groningen.       # 
+# PLEASE CITE THIS SOFTWARE AS:                                        #
+# Berends MS, Luz CF, Friedrich AW, et al. (2022).                     #
+# AMR: An R Package for Working with Antimicrobial Resistance Data.    #
+# Journal of Statistical Software, 104(3), 1-31.                       #
+# https://doi.org/10.18637/jss.v104.i03                                #
+#                                                                      #
+# Developed at the University of Groningen and the University Medical  #
+# Center Groningen in The Netherlands, in collaboration with many      #
+# colleagues from around the world, see our website.                   #
 #                                                                      #
 # This R package is free software; you can freely use and distribute   #
 # it for both personal and commercial purposes under the terms of the  #
@@ -20,17 +24,21 @@
 # useful, but it comes WITHOUT ANY WARRANTY OR LIABILITY.              #
 #                                                                      #
 # Visit our website for the full manual and a complete tutorial about  #
-# how to conduct AMR data analysis: https://msberends.github.io/AMR/   #
+# how to conduct AMR data analysis: https://amr-for-r.org              #
 # ==================================================================== #
 
-context("bug_drug_combinations.R")
-
-test_that("bug_drug_combinations works", {
+test_that("test-bug/drug.R", {
   skip_on_cran()
-  
+
   b <- suppressWarnings(bug_drug_combinations(example_isolates))
-  expect_s3_class(b, "bug_drug_combinations")
-  expect_output(print(b))
+  expect_inherits(b, "bug_drug_combinations")
+  expect_output(suppressMessages(print(b)))
   expect_true(is.data.frame(format(b)))
-  expect_true(is.data.frame(format(b, combine_IR = TRUE, add_ab_group = FALSE)))
+  expect_true(is.data.frame(format(b, add_ab_group = FALSE)))
+  if (AMR:::pkg_is_available("dplyr", min_version = "1.0.0", also_load = TRUE)) {
+    expect_true(example_isolates %>%
+      group_by(ward) %>%
+      bug_drug_combinations(FUN = mo_gramstain) %>%
+      is.data.frame())
+  }
 })
