@@ -1,15 +1,19 @@
 # ==================================================================== #
-# TITLE                                                                #
-# Antimicrobial Resistance (AMR) Data Analysis for R                   #
+# TITLE:                                                               #
+# AMR: An R Package for Working with Antimicrobial Resistance Data     #
 #                                                                      #
-# SOURCE                                                               #
+# SOURCE CODE:                                                         #
 # https://github.com/msberends/AMR                                     #
 #                                                                      #
-# LICENCE                                                              #
-# (c) 2018-2021 Berends MS, Luz CF et al.                              #
-# Developed at the University of Groningen, the Netherlands, in        #
-# collaboration with non-profit organisations Certe Medical            #
-# Diagnostics & Advice, and University Medical Center Groningen.       # 
+# PLEASE CITE THIS SOFTWARE AS:                                        #
+# Berends MS, Luz CF, Friedrich AW, et al. (2022).                     #
+# AMR: An R Package for Working with Antimicrobial Resistance Data.    #
+# Journal of Statistical Software, 104(3), 1-31.                       #
+# https://doi.org/10.18637/jss.v104.i03                                #
+#                                                                      #
+# Developed at the University of Groningen and the University Medical  #
+# Center Groningen in The Netherlands, in collaboration with many      #
+# colleagues from around the world, see our website.                   #
 #                                                                      #
 # This R package is free software; you can freely use and distribute   #
 # it for both personal and commercial purposes under the terms of the  #
@@ -20,28 +24,32 @@
 # useful, but it comes WITHOUT ANY WARRANTY OR LIABILITY.              #
 #                                                                      #
 # Visit our website for the full manual and a complete tutorial about  #
-# how to conduct AMR data analysis: https://msberends.github.io/AMR/   #
+# how to conduct AMR data analysis: https://amr-for-r.org              #
 # ==================================================================== #
 
-context("kurtosis.R")
-
-test_that("kurtosis works", {
+test_that("test-kurtosis.R", {
   skip_on_cran()
+
   expect_equal(kurtosis(example_isolates$age),
-               3.549319,
-               tolerance = 0.00001)
-  
+    5.227999,
+    tolerance = 0.00001
+  )
+
   expect_equal(unname(kurtosis(data.frame(example_isolates$age))),
-               3.549319,
-               tolerance = 0.00001)
+    5.227999,
+    tolerance = 0.00001
+  )
   expect_equal(unname(kurtosis(data.frame(example_isolates$age), excess = TRUE)),
-               0.549319,
-               tolerance = 0.00001)
-  
+    2.227999,
+    tolerance = 0.00001
+  )
+
   expect_equal(kurtosis(matrix(example_isolates$age)),
-               3.549319,
-               tolerance = 0.00001)
+    5.227999,
+    tolerance = 0.00001
+  )
   expect_equal(kurtosis(matrix(example_isolates$age), excess = TRUE),
-               0.549319,
-               tolerance = 0.00001)
+    2.227999,
+    tolerance = 0.00001
+  )
 })
